@@ -245,7 +245,10 @@ def paginate(text: str) -> Iterator[str]:
 
 
 def command(
-    allow_dm: bool = True, aliases: Optional[List[str]] = None, admin_only=False
+    allow_dm: bool = True,
+    aliases: Optional[List[str]] = None,
+    admin_only=False,
+    help_group=None,
 ) -> Callable:
     """Decorator for bot command methods."""
 
@@ -258,6 +261,7 @@ def command(
         cast(Any, wrapped).allow_dm = allow_dm
         cast(Any, wrapped).aliases = aliases
         cast(Any, wrapped).admin_only = admin_only
+        cast(Any, wrapped).help_group = help_group
         return wrapped
 
     return callable
@@ -750,6 +754,7 @@ class SpellBot(discord.Client):
             if len(found_discord_users) == game.size:  # game is ready
                 game.url = self.create_game() if game.system == "spelltable" else None
                 game.status = "started"
+                game.game_power = game.power
                 session.commit()
                 for discord_user in found_discord_users:
                     await discord_user.send(embed=game.to_embed(dm=True))
@@ -816,10 +821,14 @@ class SpellBot(discord.Client):
     # Any method of this class with a name that is decorated by @command is detected as a
     # bot command. These methods should have a signature like:
     #
-    #     @command(allow_dm=True)
-    #     def command_name(self, prefix, params, message)
+    #     @command(allow_dm=True, aliases=["whatever"], admin_only=False, help_group="Hi")
+    #     def command_name(self, session, prefix, params, message)
     #
     # - `allow_dm` indicates if the command is allowed to be used in direct messages.
+    # - `aliases` is a list alternative ways for users to run this command.
+    # - `admin_only` indicates if the command is available only to admins.
+    # - `help_group` is the group name for this command in the usage help response.
+    # - `session` is a database session, you must commit any changes you make.
     # - `prefix` is the command prefix, which is "!" by default.
     # - `params` are any space delimitered parameters also sent with the command.
     # - `message` is the discord.py message object that triggered the command.
@@ -832,7 +841,7 @@ class SpellBot(discord.Client):
     #
     # Where [foo] indicates foo is optional and <bar> indicates bar is required.
 
-    @command(allow_dm=True)
+    @command(allow_dm=True, help_group="Commands for Players")
     async def help(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -840,8 +849,21 @@ class SpellBot(discord.Client):
         Sends you this help message.
         """
         usage = ""
-        for command in sorted(set(self._commands.values())):
-            method = getattr(self, command)
+        command_methods = [
+            getattr(self, command) for command in set(self._commands.values())
+        ]
+
+        def method_sort_key(method):
+            return method.help_group + method.__name__
+
+        help_group: Optional[str] = None
+        for method in sorted(command_methods, key=method_sort_key, reverse=True):
+            if not help_group or method.help_group != help_group:
+                help_group = method.help_group
+                assert help_group
+                bar = "#" * (18 + len(help_group))
+                usage += f"\n```fix\n{bar}\n###      {help_group}      ###\n{bar}\n```"
+
             doc = method.__doc__.split("&")
             cmd_params: List[str] = [param.strip() for param in doc[1:]]
             use, cmd_params_use = doc[0], ", ".join(cmd_params)
@@ -863,7 +885,7 @@ class SpellBot(discord.Client):
                 aliases_s = ", ".join(sorted([f"`{prefix}{m}`" for m in method.aliases]))
                 use += f"\n> \n> Aliases: {aliases_s}"
 
-            title = f"{prefix}{command}"
+            title = f"{prefix}{method.__name__}"
             if cmd_params_use:
                 title = f"{title} {cmd_params_use}"
             usage += f"\n`{title}`"
@@ -884,13 +906,11 @@ class SpellBot(discord.Client):
             "<https://ko-fi.com/Y8Y51VTHZ>"
         )
         if str(message.channel.type) != "private":
-            await message.channel.send(
-                s("dm_sent", reply=f"<@{cast(discord.User, message.author).id}>")
-            )
+            await message.add_reaction("✅")
         for page in paginate(usage):
             await message.author.send(page)
 
-    @command(allow_dm=True)
+    @command(allow_dm=True, help_group="Commands for Players")
     async def about(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1123,6 +1143,7 @@ class SpellBot(discord.Client):
                 if len(found_discord_users) == game.size:  # game is ready
                     game.url = self.create_game() if game.system == "spelltable" else None
                     game.status = "started"
+                    game.game_power = game.power
                     session.commit()
                     for discord_user in found_discord_users:
                         await discord_user.send(embed=game.to_embed(dm=True))
@@ -1166,7 +1187,12 @@ class SpellBot(discord.Client):
             await post.add_reaction("➕")
             await post.add_reaction("➖")
 
-    @command(allow_dm=False, aliases=["signup"], admin_only=True)
+    @command(
+        allow_dm=False,
+        aliases=["signup"],
+        admin_only=True,
+        help_group="Commands for Admins",
+    )
     async def queue(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1187,7 +1213,7 @@ class SpellBot(discord.Client):
             session, prefix, params, message, create_new_game=True, use_queue=True
         )
 
-    @command(allow_dm=False, aliases=["play"])
+    @command(allow_dm=False, aliases=["play"], help_group="Commands for Players")
     async def lfg(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1214,7 +1240,9 @@ class SpellBot(discord.Client):
             session, prefix, params, message, create_new_game=True, use_queue=False
         )
 
-    @command(allow_dm=False, aliases=["join", "search"])
+    @command(
+        allow_dm=False, aliases=["join", "search"], help_group="Commands for Players"
+    )
     async def find(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1277,13 +1305,17 @@ class SpellBot(discord.Client):
             session.commit()
         else:
             await message.channel.send(
-                s("report_wrong", reply=f"<@{cast(discord.User, message.author).id}>")
+                s(
+                    "report_wrong",
+                    reply=f"<@{cast(discord.User, message.author).id}>",
+                    prefix=prefix,
+                )
             )
             return False
 
         return True
 
-    @command(allow_dm=False, aliases=["results"])
+    @command(allow_dm=False, aliases=["results"], help_group="Commands for Players")
     async def report(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1307,7 +1339,10 @@ class SpellBot(discord.Client):
             return
 
         game: Optional[Game] = None
-        if req.lower().startswith("sb") and req[2:].isdigit():
+        if req.lower().startswith("#sb") and req[3:].isdigit():
+            game_id = int(req[3:])
+            game = session.query(Game).filter(Game.id == game_id).one_or_none()
+        elif req.lower().startswith("sb") and req[2:].isdigit():
             game_id = int(req[2:])
             game = session.query(Game).filter(Game.id == game_id).one_or_none()
         elif req.isdigit():
@@ -1346,7 +1381,7 @@ class SpellBot(discord.Client):
             s("report", reply=f"<@{cast(discord.User, message.author).id}>")
         )
 
-    @command(allow_dm=False, admin_only=False)
+    @command(allow_dm=False, admin_only=False, help_group="Commands for Players")
     async def points(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1377,7 +1412,7 @@ class SpellBot(discord.Client):
                     )
                 )
 
-    @command(allow_dm=False, admin_only=True)
+    @command(allow_dm=False, admin_only=True, help_group="Commands for Admins")
     async def event(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1578,7 +1613,7 @@ class SpellBot(discord.Client):
             )
         )
 
-    @command(allow_dm=False, admin_only=True)
+    @command(allow_dm=False, admin_only=True, help_group="Commands for Admins")
     async def begin(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1634,6 +1669,7 @@ class SpellBot(discord.Client):
 
             game.url = self.create_game() if game.system == "spelltable" else None
             game.status = "started"
+            game.game_power = game.power
             response = game.to_embed(dm=True)
             session.commit()
 
@@ -1650,7 +1686,7 @@ class SpellBot(discord.Client):
                 )
             )
 
-    @command(allow_dm=False, admin_only=True)
+    @command(allow_dm=False, admin_only=True, help_group="Commands for Admins")
     async def game(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1764,7 +1800,7 @@ class SpellBot(discord.Client):
             )
         )
 
-    @command(allow_dm=True, aliases=["quit", "exit"])
+    @command(allow_dm=True, aliases=["quit", "exit"], help_group="Commands for Players")
     async def leave(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1786,7 +1822,7 @@ class SpellBot(discord.Client):
         )
         await self.try_to_update_game(game)
 
-    @command(allow_dm=False, admin_only=True)
+    @command(allow_dm=False, admin_only=True, help_group="Commands for Admins")
     async def export(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1828,7 +1864,7 @@ class SpellBot(discord.Client):
                 )
         await message.channel.send("", file=discord.File(export_file))
 
-    @command(allow_dm=True)
+    @command(allow_dm=True, help_group="Commands for Players")
     async def power(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1839,11 +1875,18 @@ class SpellBot(discord.Client):
         you in games with other players of similar power levels.
         & <none | 1..10>
         """
-        if not params:
+
+        async def send_invalid(prepend) -> None:
             await message.channel.send(
-                s("power_invalid", reply=f"<@{cast(discord.User, message.author).id}>")
+                s(
+                    "power_invalid",
+                    reply=f"<@{cast(discord.User, message.author).id}>",
+                    prepend=prepend,
+                )
             )
-            return
+
+        if not params:
+            return await send_invalid("")
 
         user = self.ensure_user_exists(session, message.author)
 
@@ -1851,35 +1894,31 @@ class SpellBot(discord.Client):
         if power in ["none", "off", "unset", "no", "0"]:
             user.power = None
             session.commit()
-            await message.channel.send(
-                s(
-                    "power",
-                    reply=f"<@{cast(discord.User, message.author).id}>",
-                    power="none",
-                )
-            )
+            await message.add_reaction("✅")
             return
 
+        if power == "unlimited":
+            return await send_invalid("⚡ ")
+
         if not power.isdigit():
-            await message.channel.send(
-                s("power_invalid", reply=f"<@{cast(discord.User, message.author).id}>")
-            )
-            return
+            return await send_invalid("")
 
         power_i = int(power)
         if not (1 <= power_i <= 10):
-            await message.channel.send(
-                s("power_invalid", reply=f"<@{cast(discord.User, message.author).id}>")
-            )
-            return
+            prepend = ""
+            if power_i == 11:
+                prepend = "🤘 "
+            elif power_i == 9000:
+                prepend = "💥 "
+            elif power_i == 42:
+                prepend = "🤖 "
+            return await send_invalid(prepend)
 
         user.power = power_i
         session.commit()
-        await message.channel.send(
-            s("power", reply=f"<@{cast(discord.User, message.author).id}>", power=power_i)
-        )
+        await message.add_reaction("✅")
 
-    @command(allow_dm=True)
+    @command(allow_dm=True, help_group="Commands for Players")
     async def team(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
@@ -1958,16 +1997,9 @@ class SpellBot(discord.Client):
             )
             session.add(user_team)
         session.commit()
+        await message.add_reaction("✅")
 
-        await message.channel.send(
-            s(
-                "team",
-                reply=f"<@{cast(discord.User, message.author).id}>",
-                team=team_found.name,
-            ),
-        )
-
-    @command(allow_dm=False)
+    @command(allow_dm=False, help_group="Commands for Admins")
     async def spellbot(
         self, session: Session, prefix: str, params: List[str], message: discord.Message
     ) -> None:
